////////////////////////////////////////////////////////////////
//                                               //
////////////////////////////////////////////////////////////////

unit UCodeTable;

interface

uses  Grids,SysUtils;

type
     TCodeTable =class     //   
     private
       FSG :TStringGrid;                   // 
       function IntToHex(B:byte):char;     //  
       function WinToDos(S:string):string; //   Win  Dos 
       function DosToWin(S:string):string; //   Dos  Win 
     public
       constructor Create;                 //   
       destructor Destroy; override;       //   
       procedure Clear;                    //  
       procedure RunWin;                   //    Windows
       procedure RunDos;                   //    Dos
       function DecToHex(B:byte):string;   //  
       property Grid:TStringGrid read FSG write FSG;  // 
     end;

var  CodeTable :TCodeTable;   //  

implementation

uses  Windows;


function TCodeTable.IntToHex(B:byte):char;  //  
const  C = '0123456789ABCDEF';
begin
     if B<16 then result:=C[B+1] else result:=' ';
end;

function TCodeTable.DecToHex(B:byte):string;  //  
begin
     result:=IntToHex(B div 16)+IntToHex(B and $0F);
end;

function TCodeTable.WinToDos(S:string):string;  //   Win  Dos 
var  Len :longint;  //  
begin
     result:='';  if S='' then Exit;
     Len:=Length(S);
     SetLength(result, Len);
     CharToOemBuff(PChar(S), PChar(result), Len);
end;

function TCodeTable.DosToWin(S:string):string;  //   Dos  Win 
var  Len :longint;  //  
begin
     result:='';  if S='' then Exit;
     Len:=Length(S);
     SetLength(result, Len);
     OemToCharBuff(PChar(S), PChar(result), Len);
end;

constructor TCodeTable.Create;  //   
begin
     FSG:=nil;
end;

destructor TCodeTable.Destroy;  //   
begin
     FSG:=nil;
end;

procedure TCodeTable.Clear;  //  
var  L,C :longint;  // , 
begin
     if FSG=nil then Exit;
     //  
     for L:=0 to 15 do begin
         FSG.Cells[L+1,0]:=IntToHex(L);
         FSG.Cells[0,L+1]:=IntToHex(L);
     end;
     //  
     for L:=0 to 15 do begin
         for C:=0 to 15 do begin
             FSG.Cells[C+1,L+1]:='';
         end;
     end;
end;

procedure TCodeTable.RunWin;  //    Windows
var  L,C :longint;  // , 
begin
     if FSG=nil then Exit;
     for L:=0 to 15 do begin
         for C:=0 to 15 do begin
             FSG.Cells[C+1,L+1]:=Chr(L*16+C);
         end;
     end;
end;

procedure TCodeTable.RunDos;  //    Dos
var  L,C :longint;  // , 
begin
     if FSG=nil then Exit;
     for L:=0 to 15 do begin
         for C:=0 to 15 do begin
             FSG.Cells[C+1,L+1]:=DosToWin(Chr(L*16+C));
         end;
     end;
end;


initialization
    CodeTable := TCodeTable.Create;  //   
finalization
    CodeTable.Free;                  //   
end.
